@@ -1,18 +1,31 @@
-# Copyright (c) 2003-2014 LOGILAB S.A. (Paris, FRANCE).
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
-#
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation; either version 2 of the License, or (at your option) any later
-# version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details
-#
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+# -*- coding: utf-8 -*-
+# Copyright (c) 2006-2015 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
+# Copyright (c) 2008 Fabrice Douchant <Fabrice.Douchant@logilab.fr>
+# Copyright (c) 2009 Mads Kiilerich <mads@kiilerich.com>
+# Copyright (c) 2009 Vincent
+# Copyright (c) 2011-2014 Google, Inc.
+# Copyright (c) 2012 Kevin Jing Qiu <kevin.jing.qiu@gmail.com>
+# Copyright (c) 2012 David Pursehouse <david.pursehouse@sonymobile.com>
+# Copyright (c) 2012 JT Olds <jtolds@xnet5.com>
+# Copyright (c) 2012 FELD Boris <lothiraldan@gmail.com>
+# Copyright (c) 2014 Brett Cannon <brett@python.org>
+# Copyright (c) 2014-2016 Claudiu Popa <pcmanticore@gmail.com>
+# Copyright (c) 2014 Arun Persaud <arun@nubati.net>
+# Copyright (c) 2014 Dan Goldsmith <djgoldsmith@googlemail.com>
+# Copyright (c) 2014 Daniel Harding <dharding@living180.net>
+# Copyright (c) 2014-2015 Michal Nowikowski <godfryd@gmail.com>
+# Copyright (c) 2014 Alexandru Coman <fcoman@bitdefender.com>
+# Copyright (c) 2015 Aru Sahni <arusahni@gmail.com>
+# Copyright (c) 2015 Simu Toni <simutoni@gmail.com>
+# Copyright (c) 2015 Steven Myint <hg@stevenmyint.com>
+# Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
+# Copyright (c) 2015 Florian Bruhin <me@the-compiler.org>
+# Copyright (c) 2015 Mihai Balint <balint.mihai@gmail.com>
+# Copyright (c) 2016 Alan Evangelista <alanoe@linux.vnet.ibm.com>
+
+# Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
+# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+
 """ %prog [options] module_or_package
 
   Check that a module satisfies a coding standard (and more !).
@@ -36,8 +49,8 @@ try:
 except ImportError:
     multiprocessing = None
 import sys
-import tokenize
 import warnings
+import tokenize
 
 import six
 
@@ -226,7 +239,7 @@ if multiprocessing is not None:
             if self._plugins:
                 linter.load_plugin_modules(self._plugins)
 
-            linter.load_configuration(**self._config)
+            linter.load_configuration_from_config(self._config)
             linter.set_reporter(reporters.CollectingReporter())
 
             # Enable the Python 3 checker mode. This option is
@@ -275,6 +288,13 @@ class PyLinter(config.OptionsManagerMixIn,
                   'dest' : 'black_list', 'default' : ('CVS',),
                   'help' : 'Add files or directories to the blacklist. '
                            'They should be base names, not paths.'}),
+
+                ('ignore-patterns',
+                 {'type' : 'regexp_csv', 'metavar' : '<pattern>[,<pattern>...]',
+                  'dest' : 'black_list_re', 'default' : (),
+                  'help' : 'Add files or directories matching the regex patterns to the'
+                           ' blacklist. The regex matches against base names, not paths.'}),
+
                 ('persistent',
                  {'default': True, 'type' : 'yn', 'metavar' : '<y_or_n>',
                   'level': 1,
@@ -302,7 +322,8 @@ class PyLinter(config.OptionsManagerMixIn,
                   'help' : 'Put messages in a separate file for each module / '
                            'package specified on the command line instead of printing '
                            'them on stdout. Reports (if any) will be written in a file '
-                           'name "pylint_global.[txt|html]".'}),
+                           'name "pylint_global.[txt|html]". This option is deprecated and '
+                           'it will be removed in Pylint 2.0.'}),
 
                 ('reports',
                  {'default': 1, 'type' : 'yn', 'metavar' : '<y_or_n>',
@@ -341,7 +362,9 @@ class PyLinter(config.OptionsManagerMixIn,
                   'group': 'Messages control',
                   'help' : 'Enable the message, report, category or checker with the '
                            'given id(s). You can either give multiple identifier '
-                           'separated by comma (,) or put this option multiple time. '
+                           'separated by comma (,) or put this option multiple time '
+                           '(only on the command line, not in the configuration file '
+                           'where it should appear only once). '
                            'See also the "--disable" option for examples. '}),
 
                 ('disable',
@@ -370,9 +393,6 @@ class PyLinter(config.OptionsManagerMixIn,
                             'See doc for all details')
                  }),
 
-                ('include-ids', utils.deprecated_option('i', 'yn', INCLUDE_IDS_HELP)),
-                ('symbols', utils.deprecated_option('s', 'yn', SYMBOLS_HELP)),
-
                 ('jobs',
                  {'type' : 'int', 'metavar': '<n-processes>',
                   'short': 'j',
@@ -404,7 +424,8 @@ class PyLinter(config.OptionsManagerMixIn,
                            'Joining a lot of strings can lead to a maximum '
                            'recursion error in Pylint and this flag can prevent '
                            'that. It has one side effect, the resulting AST '
-                           'will be different than the one from reality.')}
+                           'will be different than the one from reality. '
+                           'This option is deprecated and it will be removed in Pylint 2.0.')}
                 ),
                )
 
@@ -575,7 +596,8 @@ class PyLinter(config.OptionsManagerMixIn,
 
     def disable_noerror_messages(self):
         for msgcat, msgids in six.iteritems(self.msgs_store._msgs_by_category):
-            if msgcat == 'E':
+            # enable only messages with 'error' severity and above ('fatal')
+            if msgcat in ['E', 'F']:
                 for msgid in msgids:
                     self.enable(msgid)
             else:
@@ -689,9 +711,8 @@ class PyLinter(config.OptionsManagerMixIn,
         # get needed checkers
         neededcheckers = [self]
         for checker in self.get_checkers()[1:]:
-            # fatal errors should not trigger enable / disabling a checker
             messages = set(msg for msg in checker.msgs
-                           if msg[0] != 'F' and self.is_message_enabled(msg))
+                           if self.is_message_enabled(msg))
             if (messages or
                     any(self.report_is_enabled(r[0]) for r in checker.reports)):
                 neededcheckers.append(checker)
@@ -737,8 +758,8 @@ class PyLinter(config.OptionsManagerMixIn,
                 self._parallel_check(files_or_modules)
 
     def _get_jobs_config(self):
-        child_config = {}
-        filter_options = {'symbols', 'include-ids', 'long-help'}
+        child_config = collections.OrderedDict()
+        filter_options = {'long-help'}
         filter_options.update((opt_name for opt_name, _ in self._external_opts))
         for opt_providers in six.itervalues(self._all_options):
             for optname, optdict, val in opt_providers.options_and_values():
@@ -875,7 +896,8 @@ class PyLinter(config.OptionsManagerMixIn,
     def expand_files(self, modules):
         """get modules and errors from a list of modules and handle errors
         """
-        result, errors = utils.expand_modules(modules, self.config.black_list)
+        result, errors = utils.expand_modules(modules, self.config.black_list,
+                                              self.config.black_list_re)
         for error in errors:
             message = modname = error["mod"]
             key = error["key"]
@@ -964,6 +986,9 @@ class PyLinter(config.OptionsManagerMixIn,
 
         if persistent run, pickle results for later comparison
         """
+        # Display whatever messages are left on the reporter.
+        self.reporter.display_messages(report_nodes.Section())
+
         if self.file_state.base_name is not None:
             # load previous results if any
             previous_stats = config.load_results(self.file_state.base_name)
@@ -976,17 +1001,12 @@ class PyLinter(config.OptionsManagerMixIn,
                     self.reporter.set_output(open(filename, 'w'))
             else:
                 sect = report_nodes.Section()
-            if self.config.reports or self.config.output_format == 'html':
-                self.reporter.display_results(sect)
+            if self.config.reports:
+                self.reporter.display_reports(sect)
             # save results if persistent run
             if self.config.persistent:
                 config.save_results(self.stats, self.file_state.base_name)
         else:
-            if self.config.output_format == 'html':
-                # No output will be emitted for the html
-                # reporter if the file doesn't exist, so emit
-                # the results here.
-                self.reporter.display_results(report_nodes.Section())
             self.reporter.on_close(self.stats, {})
 
     # specific reports ########################################################
@@ -1227,8 +1247,6 @@ group are mutually exclusive.'),
                        'disabled and only messages emitted by the porting '
                        'checker will be displayed'}),
 
-            ('profile', utils.deprecated_option(opt_type='yn')),
-
             ), option_groups=self.option_groups, pylintrc=self._rcfile)
         # register standard checkers
         linter.load_default_plugins()
